import React from 'react';
import ReactDOM from 'react-dom';
import TagManager from 'react-gtm-module';
import {
  Chart,
  LineController,
  CategoryScale,
  LinearScale,
  PointElement,
  DoughnutController,
  LineElement,
  ArcElement,
  BarController,
  BarElement,
  Tooltip,
  Legend,
  Title,
  LogarithmicScale,
  TimeScale,
  Filler
} from 'chart.js';
import ChartDataLabels from 'chartjs-plugin-datalabels';
import zoomPlugin from 'chartjs-plugin-zoom';
import 'chartjs-adapter-moment';

import { queryClient, setupAxiosInterceptors, initializeQueryDefaults } from './internal';
import { Root } from './Root';
// import './style.css';

// 1. set up axios interceptor
// setupAxiosInterceptors();

// 3. initialize react query

initializeQueryDefaults(queryClient);
setupAxiosInterceptors(queryClient);

// Register stuff we'll be using with Chart.js
Chart.register([
  LineController,
  DoughnutController,
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  ArcElement,
  BarController,
  BarElement,
  Tooltip,
  Legend,
  Title,
  ChartDataLabels,
  zoomPlugin,
  LogarithmicScale,
  TimeScale,
  Filler
]);

// 4. analytics set up
const gtmId = process.env.GTM_ID || import.meta.env?.VITE_GTM_ID;
if (gtmId) {
  TagManager.initialize({
    gtmId: gtmId,
    dataLayerName: 'app'
  });
}

ReactDOM.render(<Root />, document.getElementById('root'));
